==> instant3Dhub-ansibledb-noarch-22.1.tgz: ansible/PostgreSQL/roles/instant3DhubInitPGSQL/files/components/spaceStoreCreateDBTables.sql <==
set statement_timeout = 0;
set client_encoding = 'utf8';
set standard_conforming_strings = on;
set check_function_bodies = false;
set client_min_messages = warning;

create schema if not exists store;
alter schema store owner to i3dhub;

create table if not exists store.spaces
(
    id           bigserial primary key,
    ext_space_id varchar not null unique,
    description  varchar not null default '',
    insert_date  timestamptz
    -- todo: custom fields
);

create index if not exists idx_spaces on store.spaces (ext_space_id);

create table if not exists store.revisions
(
    id          bigserial primary key,
    space_id    bigserial references store.spaces (id) on delete cascade,
    revision    integer,
    name        text not null default '',
    size        integer,
    insert_date timestamptz,
    last_read   timestamptz,
    data        text not null,
    unique (space_id, revision)
    -- todo: custom fields
);

create table if not exists store.tags
(
    id       bigserial primary key,
    value    varchar,
    space_id bigserial references store.spaces (id) on delete cascade
);


create table if not exists store.attachments
(
    id                bigserial primary key,
    ext_attachment_id varchar not null,
    attachment_data   bytea   not null,
    data_size         integer,
    insert_date       timestamptz,
    last_read         timestamptz
);

create index if not exists idx_attachments on store.attachments (ext_attachment_id);

create table if not exists store.space_revision_attachments
(
    id            bigserial primary key,
    revision_id   bigserial references store.revisions (id) on delete cascade,
    attachment_id bigserial references store.attachments (id) on delete cascade
);

create or replace function store.find_spaces(p_tags varchar(40)[])
    returns table
            (
                id bigint
            )
as
$body$
begin
    return query (
        select s.id
        from store.spaces s,
             store.tags t
        where (t.value = all (p_tags) or p_tags is null)
          and s.id = t.space_id
    );
end
$body$
    language 'plpgsql';

==> instant3Dhub-ansibledb-noarch-23.2.tgz: ansible/PostgreSQL/roles/instant3DhubInitPGSQL/files/components/spaceStoreCreateDBTables.sql <==
set statement_timeout = 0;
set client_encoding = 'utf8';
set standard_conforming_strings = on;
set check_function_bodies = false;
set client_min_messages = warning;

create schema if not exists store;
alter schema store owner to i3dhub;

create table if not exists store.spaces
(
    id           bigserial primary key,
    ext_space_id varchar not null unique,
    description  varchar not null default '',
    insert_date  timestamptz
    -- todo: custom fields
);

create index if not exists idx_spaces on store.spaces (ext_space_id);

create table if not exists store.revisions
(
    id          bigserial primary key,
    space_id    bigserial references store.spaces (id) on delete cascade,
    revision    integer,
    name        text not null default '',
    size        integer,
    insert_date timestamptz,
    last_read   timestamptz,
    data        text not null,
    unique (space_id, revision)
    -- todo: custom fields
);

create table if not exists store.tags
(
    id       bigserial primary key,
    value    varchar,
    space_id bigserial references store.spaces (id) on delete cascade
);


create table if not exists store.attachments
(
    id                bigserial primary key,
    ext_attachment_id varchar not null,
    attachment_data   bytea   not null,
    data_size         integer,
    insert_date       timestamptz,
    last_read         timestamptz
);

create table if not exists store.schema_migrations
(
    "version" int8 not null,
    dirty     bool not null,
    constraint schema_migrations_pkey primary key (version)
);

create index if not exists idx_attachments on store.attachments (ext_attachment_id);

create table if not exists store.space_revision_attachments
(
    id            bigserial primary key,
    revision_id   bigserial references store.revisions (id) on delete cascade,
    attachment_id bigserial references store.attachments (id) on delete cascade
);

create or replace function store.find_spaces(p_tags varchar(40)[])
    returns table
            (
                id bigint
            )
as
$body$
begin
    return query (select s.id
                  from store.spaces s,
                       store.tags t
                  where (t.value = all (p_tags) or p_tags is null)
                    and s.id = t.space_id);
end
$body$
    language 'plpgsql';
